OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Loit kaksivaiheisen tunnistautumisen varakoodit tilillesi",
    "Second-factor backup codes" : "Kaksivaiheisen tunnistautumisen varakoodit",
    "Generate backup codes" : "Luo varakoodit",
    "Backup code" : "Varakoodi",
    "Use backup code" : "Käytä varakoodia",
    "Two factor backup codes" : "Kaksivaiheiden tunnistautumisen varakoodit",
    "An error occurred while generating your backup codes" : "Tapahtui virhe varakoodeja luotaessa",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Varakoodit on luotu. {used}/{total} koodia on käytetty.",
    "Save backup codes" : "Tallenna varakoodit",
    "Print backup codes" : "Tulosta varakoodit",
    "Regenerate backup codes" : "Luo varakoodit uudelleen",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Jos luot varakoodit uudelleen, vanhat koodit poistetaan automaattisesti käytöstä.",
    "Submit" : "Lähetä"
},
"nplurals=2; plural=(n != 1);");
